@@ -194,6 +194,7 @@ Red        => Buffer's file was modified on disk by an external process.
 Indianred2 => Buffer exists but its file has been deleted.
 Orange     => Buffer is modified and not saved to disk.
 Italic     => A non-file buffer.
+Yellow     => Tramp archive buffer.
 
 ** Commands
 \\<helm-buffer-map>
@@ -211,6 +212,7 @@ Italic     => A non-file buffer.
 \\[helm-buffer-save-persistent]\t\tSave buffer without leaving Helm.
 \\[helm-buffer-run-kill-buffers]\t\tDelete marked buffers and leave Helm.
 \\[helm-buffer-run-kill-persistent]\t\tDelete buffer without leaving Helm.
+\\[helm-buffer-run-rename-buffer]\t\tRename buffer.
 \\[helm-toggle-all-marks]\t\tToggle all marks.
 \\[helm-mark-all]\t\tMark all.
 \\[helm-toggle-buffers-details]\t\tToggle details.
@@ -621,8 +623,8 @@ You can open a dired buffer containing only marked files with `\\<helm-find-file
 With a prefix argument you can open this same dired buffer in wdired mode for
 editing.  Note that wildcards are supported as well, so you can use e.g.
 \"*.txt\" to select all \".txt\" files in the current directory or \"**.txt\" to
-select all files recursively from the current directory.  See [[Using wildcard to
-select multiple files]] section above.
+select all files recursively from the current directory.
+See [[Use the wildcard to select multiple files]] section above.
 
 *** Defining default target directory for copying, renaming, etc
 
@@ -783,8 +785,34 @@ this files in separate windows using an horizontal layout or a
 vertical layout if you used a prefix arg, when no more windows can be
 displayed in frame, next files are opened in background without being
 displayed.  When using \\<helm-find-files-map>\\[helm-ff-run-switch-other-window] the current
-buffer is kept and files are displayed next to it.
+buffer is kept and files are displayed next to it with same behavior as above.
+When using two prefix args, files are opened in background without beeing displayed.
 
+*** Expand archives as directories in a avfs directory
+
+If you have mounted your filesystem with mountavfs,
+you can expand archives in the \"~/.avfs\" directory with \\<helm-map>\\[helm-execute-persistent-action].
+
+*** Tramp archive support (emacs-27+ only)
+
+If your emacs have library tramp-archive.el, you can browse the
+content of archives with emacs and BTW helm-find-files. However this beeing
+experimental and not very fast, helm doesn't provide an automatic
+expansion and detection of archives, you will have to add the final /
+manually and may have to force update (\\<helm-map>\\[helm-refresh])
+or remove and add again the final / until tramp finish decompressing archive.
+
+*** Touch files
+
+In the completion buffer, you can choose the default which is the current-time, it is
+the first candidate or the timestamp of one of the selected files.
+If you need to use something else, use \\<helm-map>\\[next-history-element] and edit
+the date in minibuffer.
+It is also a way to quickly create a new file without opening a buffer, saving it
+and killing it.
+To touch more than one new file, separate you filenames with a comma (\",\").
+If one wants to create (touch) a new file with comma inside the name use a prefix arg,
+this will prevent splitting the name and create multiple files.
 
 ** Commands
 \\<helm-find-files-map>
@@ -798,14 +826,15 @@ buffer is kept and files are displayed next to it.
 \\[helm-ff-run-git-grep]\t\tRun git-grep on current directory.
 \\[helm-ff-run-gid]\t\tRun gid (id-utils).
 \\[helm-ff-run-etags]\t\tRun Etags (`\\[universal-argument]' to use thing-at-point, `\\[universal-argument] \\[universal-argument]' to reload cache).
-\\[helm-ff-run-rename-file]\t\tRename File (`\\[universal-argument]' to follow).
+\\[helm-ff-run-rename-file]\t\tRename Files (`\\[universal-argument]' to follow).
 \\[helm-ff-run-query-replace-fnames-on-marked]\t\tQuery replace on marked files.
-\\[helm-ff-run-copy-file]\t\tCopy File (`\\[universal-argument]' to follow).
-\\[helm-ff-run-byte-compile-file]\t\tByte Compile File (`\\[universal-argument]' to load).
-\\[helm-ff-run-load-file]\t\tLoad File.
-\\[helm-ff-run-symlink-file]\t\tSymlink File.
-\\[helm-ff-run-hardlink-file]\t\tHardlink file.
-\\[helm-ff-run-delete-file]\t\tDelete File.
+\\[helm-ff-run-copy-file]\t\tCopy Files (`\\[universal-argument]' to follow).
+\\[helm-ff-run-byte-compile-file]\t\tByte Compile Files (`\\[universal-argument]' to load).
+\\[helm-ff-run-load-file]\t\tLoad Files.
+\\[helm-ff-run-symlink-file]\t\tSymlink Files.
+\\[helm-ff-run-hardlink-file]\t\tHardlink files.
+\\[helm-ff-run-delete-file]\t\tDelete Files.
+\\[helm-ff-run-touch-files]\t\tTouch files.
 \\[helm-ff-run-kill-buffer-persistent]\t\tKill buffer candidate without leaving Helm.
 \\[helm-ff-persistent-delete]\t\tDelete file without leaving Helm.
 \\[helm-ff-run-switch-to-eshell]\t\tSwitch to Eshell.
@@ -820,7 +849,7 @@ buffer is kept and files are displayed next to it.
 \\[helm-ff-rotate-left-persistent]\t\tRotate image left.
 \\[helm-ff-rotate-right-persistent]\t\tRotate image right.
 \\[helm-find-files-up-one-level]\t\tGo to parent directory.
-\\[helm-ff-run-switch-to-history]\t\tSwitch to the vistied-directory history.
+\\[helm-find-files-history]\t\tSwitch to the visited-directory history.
 \\[helm-ff-file-name-history]\t\tSwitch to file name history.
 \\[helm-ff-properties-persistent]\t\tShow file properties in a tooltip.
 \\[helm-mark-all]\t\tMark all visible candidates.
@@ -1148,7 +1177,8 @@ leaving Helm.
 \\[helm-ucs-persistent-insert]\t\tInsert character.
 \\[helm-ucs-persistent-forward]\t\tForward character.
 \\[helm-ucs-persistent-backward]\t\tBackward character.
-\\[helm-ucs-persistent-delete]\t\tDelete character backward.")
+\\[helm-ucs-persistent-delete]\t\tDelete character backward.
+\\[helm-ucs-persistent-insert-space]\t\tInsert space.")
 
 ;;; Bookmark help
 ;;
