@@ -488,11 +488,13 @@ from its directory."
   (interactive)
   (with-helm-alive-p
     (require 'helm-grep)
+    (require 'helm-elisp)
     (helm-run-after-exit
      (lambda (f)
        ;; Ensure specifics `helm-execute-action-at-once-if-one'
        ;; fns don't run here.
-       (let (helm-execute-action-at-once-if-one)
+       (let (helm-execute-action-at-once-if-one
+             helm-actions-inherit-frame-settings) ; use this-command
          (if (file-exists-p f)
              (helm-find-files-1 (file-name-directory f)
                                 (concat
